MessageBusConfig

Struct MessageBusConfig 

pub struct MessageBusConfig {
Show 13 fields pub database: Option<DatabaseConfig>, pub encoding: SerializationEncoding, pub timestamps_as_iso8601: bool, pub buffer_interval_ms: Option<u32>, pub autotrim_mins: Option<u32>, pub use_trader_prefix: bool, pub use_trader_id: bool, pub use_instance_id: bool, pub streams_prefix: String, pub stream_per_topic: bool, pub external_streams: Option<Vec<String>>, pub types_filter: Option<Vec<String>>, pub heartbeat_interval_secs: Option<u16>,
}
Configuration for MessageBus instances.

Fields

database: Option<DatabaseConfig>

The configuration for the message bus backing database.

encoding: SerializationEncoding

The encoding for database operations, controls the type of serializer used.

timestamps_as_iso8601: bool

If timestamps should be persisted as ISO 8601 strings. If false, then timestamps will be persisted as UNIX nanoseconds.

buffer_interval_ms: Option<u32>

The buffer interval (milliseconds) between pipelined/batched transactions. The recommended range if using buffered pipelining is [10, 1000] milliseconds, with a good compromise being 100 milliseconds.

autotrim_mins: Option<u32>

The lookback window in minutes for automatic stream trimming. The actual window may extend up to one minute beyond the specified value since streams are trimmed at most once every minute. This feature requires Redis version 6.2 or higher; otherwise, it will result in a command syntax error.

use_trader_prefix: bool

If a ‘trader-’ prefix is used for stream names.

use_trader_id: bool

If the trader’s ID is used for stream names.

use_instance_id: bool

If the trader’s instance ID is used for stream names. Default is false.

streams_prefix: String

The prefix for externally published stream names. Must have a database config.

stream_per_topic: bool

If true, messages will be written to separate streams per topic. If false, all messages will be written to the same stream.

external_streams: Option<Vec<String>>

The external stream keys the message bus will listen to for publishing deserialized message payloads internally.

types_filter: Option<Vec<String>>

A list of serializable types not to publish externally.

heartbeat_interval_secs: Option<u16>

The heartbeat interval (seconds).

Implementations

Source

impl MessageBusConfig

pub fn builder() -> MessageBusConfigBuilder

Create an instance of MessageBusConfig using the builder syntax