MessageBusConfigBuilder

Struct MessageBusConfigBuilder 

pub struct MessageBusConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> MessageBusConfigBuilder<S>

pub fn build(self) -> MessageBusConfig
where S: IsComplete,

Finish building and return the requested object

pub fn database( self, value: DatabaseConfig, ) -> MessageBusConfigBuilder<SetDatabase<S>>
where S::Database: IsUnset,

Optional (Some / Option setters). The configuration for the message bus backing database.

pub fn maybe_database( self, value: Option<DatabaseConfig>, ) -> MessageBusConfigBuilder<SetDatabase<S>>
where S::Database: IsUnset,

Optional (Some / Option setters). The configuration for the message bus backing database.

pub fn encoding( self, value: SerializationEncoding, ) -> MessageBusConfigBuilder<SetEncoding<S>>
where S::Encoding: IsUnset,

Optional (Some / Option setters). Default: SerializationEncoding::MsgPack.

The encoding for database operations, controls the type of serializer used.

pub fn maybe_encoding( self, value: Option<SerializationEncoding>, ) -> MessageBusConfigBuilder<SetEncoding<S>>
where S::Encoding: IsUnset,

Optional (Some / Option setters). Default: SerializationEncoding::MsgPack.

The encoding for database operations, controls the type of serializer used.

pub fn timestamps_as_iso8601( self, value: bool, ) -> MessageBusConfigBuilder<SetTimestampsAsIso8601<S>>
where S::TimestampsAsIso8601: IsUnset,

Optional (Some / Option setters). Default: false.

If timestamps should be persisted as ISO 8601 strings. If false, then timestamps will be persisted as UNIX nanoseconds.

pub fn maybe_timestamps_as_iso8601( self, value: Option<bool>, ) -> MessageBusConfigBuilder<SetTimestampsAsIso8601<S>>
where S::TimestampsAsIso8601: IsUnset,

Optional (Some / Option setters). Default: false.

If timestamps should be persisted as ISO 8601 strings. If false, then timestamps will be persisted as UNIX nanoseconds.

pub fn buffer_interval_ms( self, value: u32, ) -> MessageBusConfigBuilder<SetBufferIntervalMs<S>>
where S::BufferIntervalMs: IsUnset,

Optional (Some / Option setters). The buffer interval (milliseconds) between pipelined/batched transactions. The recommended range if using buffered pipelining is [10, 1000] milliseconds, with a good compromise being 100 milliseconds.

pub fn maybe_buffer_interval_ms( self, value: Option<u32>, ) -> MessageBusConfigBuilder<SetBufferIntervalMs<S>>
where S::BufferIntervalMs: IsUnset,

Optional (Some / Option setters). The buffer interval (milliseconds) between pipelined/batched transactions. The recommended range if using buffered pipelining is [10, 1000] milliseconds, with a good compromise being 100 milliseconds.

pub fn autotrim_mins( self, value: u32, ) -> MessageBusConfigBuilder<SetAutotrimMins<S>>
where S::AutotrimMins: IsUnset,

Optional (Some / Option setters). The lookback window in minutes for automatic stream trimming. The actual window may extend up to one minute beyond the specified value since streams are trimmed at most once every minute. This feature requires Redis version 6.2 or higher; otherwise, it will result in a command syntax error.

pub fn maybe_autotrim_mins( self, value: Option<u32>, ) -> MessageBusConfigBuilder<SetAutotrimMins<S>>
where S::AutotrimMins: IsUnset,

Optional (Some / Option setters). The lookback window in minutes for automatic stream trimming. The actual window may extend up to one minute beyond the specified value since streams are trimmed at most once every minute. This feature requires Redis version 6.2 or higher; otherwise, it will result in a command syntax error.

pub fn use_trader_prefix( self, value: bool, ) -> MessageBusConfigBuilder<SetUseTraderPrefix<S>>
where S::UseTraderPrefix: IsUnset,

Optional (Some / Option setters). Default: true.

If a ‘trader-’ prefix is used for stream names.

pub fn maybe_use_trader_prefix( self, value: Option<bool>, ) -> MessageBusConfigBuilder<SetUseTraderPrefix<S>>
where S::UseTraderPrefix: IsUnset,

Optional (Some / Option setters). Default: true.

If a ‘trader-’ prefix is used for stream names.

pub fn use_trader_id( self, value: bool, ) -> MessageBusConfigBuilder<SetUseTraderId<S>>
where S::UseTraderId: IsUnset,

Optional (Some / Option setters). Default: true.

If the trader’s ID is used for stream names.

pub fn maybe_use_trader_id( self, value: Option<bool>, ) -> MessageBusConfigBuilder<SetUseTraderId<S>>
where S::UseTraderId: IsUnset,

Optional (Some / Option setters). Default: true.

If the trader’s ID is used for stream names.

pub fn use_instance_id( self, value: bool, ) -> MessageBusConfigBuilder<SetUseInstanceId<S>>
where S::UseInstanceId: IsUnset,

Optional (Some / Option setters). Default: false.

If the trader’s instance ID is used for stream names. Default is false.

pub fn maybe_use_instance_id( self, value: Option<bool>, ) -> MessageBusConfigBuilder<SetUseInstanceId<S>>
where S::UseInstanceId: IsUnset,

Optional (Some / Option setters). Default: false.

If the trader’s instance ID is used for stream names. Default is false.

pub fn streams_prefix( self, value: String, ) -> MessageBusConfigBuilder<SetStreamsPrefix<S>>
where S::StreamsPrefix: IsUnset,

Optional (Some / Option setters). Default: "stream".to_string().

The prefix for externally published stream names. Must have a database config.

pub fn maybe_streams_prefix( self, value: Option<String>, ) -> MessageBusConfigBuilder<SetStreamsPrefix<S>>
where S::StreamsPrefix: IsUnset,

Optional (Some / Option setters). Default: "stream".to_string().

The prefix for externally published stream names. Must have a database config.

pub fn stream_per_topic( self, value: bool, ) -> MessageBusConfigBuilder<SetStreamPerTopic<S>>
where S::StreamPerTopic: IsUnset,

Optional (Some / Option setters). Default: true.

If true, messages will be written to separate streams per topic. If false, all messages will be written to the same stream.

pub fn maybe_stream_per_topic( self, value: Option<bool>, ) -> MessageBusConfigBuilder<SetStreamPerTopic<S>>
where S::StreamPerTopic: IsUnset,

Optional (Some / Option setters). Default: true.

If true, messages will be written to separate streams per topic. If false, all messages will be written to the same stream.

pub fn external_streams( self, value: Vec<String>, ) -> MessageBusConfigBuilder<SetExternalStreams<S>>
where S::ExternalStreams: IsUnset,

Optional (Some / Option setters). The external stream keys the message bus will listen to for publishing deserialized message payloads internally.

pub fn maybe_external_streams( self, value: Option<Vec<String>>, ) -> MessageBusConfigBuilder<SetExternalStreams<S>>
where S::ExternalStreams: IsUnset,

Optional (Some / Option setters). The external stream keys the message bus will listen to for publishing deserialized message payloads internally.

pub fn types_filter( self, value: Vec<String>, ) -> MessageBusConfigBuilder<SetTypesFilter<S>>
where S::TypesFilter: IsUnset,

Optional (Some / Option setters). A list of serializable types not to publish externally.

pub fn maybe_types_filter( self, value: Option<Vec<String>>, ) -> MessageBusConfigBuilder<SetTypesFilter<S>>
where S::TypesFilter: IsUnset,

Optional (Some / Option setters). A list of serializable types not to publish externally.

pub fn heartbeat_interval_secs( self, value: u16, ) -> MessageBusConfigBuilder<SetHeartbeatIntervalSecs<S>>
where S::HeartbeatIntervalSecs: IsUnset,

Optional (Some / Option setters). The heartbeat interval (seconds).

pub fn maybe_heartbeat_interval_secs( self, value: Option<u16>, ) -> MessageBusConfigBuilder<SetHeartbeatIntervalSecs<S>>
where S::HeartbeatIntervalSecs: IsUnset,

Optional (Some / Option setters). The heartbeat interval (seconds).